@@ -37,8 +37,24 @@
 extern int max_fid,now_open_files;
 extern SEM netutils_lock,stream_lock;
 
+typedef struct connect_t {
+	int			id;
+	struct sockaddr*	server;
+	int			len;
+	int			ret;
+	int			err;
+} CONNECT_T;
+
 int con_err;
 
+void
+do_connect(CONNECT_T * arg)
+{
+	errno = 0;
+	arg->ret = connect(arg->id,arg->server,arg->len);
+	arg->err = errno;
+}
+
 STREAM *
 new_connection(
 	int * cerr,
@@ -60,6 +76,8 @@ extern S_TABLE s_file_table;
 int f;
 FORK_LOCK_TBL ft;
 int con_time;
+int _errno;
+CONNECT_T c;
 
 	if ( func )
 		(*func)(0,work);
@@ -125,27 +143,31 @@ retry:
 	len = sizeof(server);
 
 con_retry:
-	errno = 0;
 	rlock_fork(&ft);
-	if (connect(id, (struct sockaddr*)&server, len) == -1) {
+	errno = 0;
+	c.id = id;
+	c.server = (struct sockaddr*)&server;
+	c.len = len;
+	ss_do((void(*)(void*))do_connect,&c);
+	if ( c.ret == -1) {
 		runlock_fork(&ft);
 		if ( ft.err ) {
 			close(id);
 			goto retry;
 		}
-		if ( errno == EINTR )
+		if ( c.err == EINTR )
 			goto con_retry;
-		if ( errno == EISCONN )
+		if ( c.err == EISCONN )
 			goto ok;
 		fprintf(stderr,"%s %x %i\n",hostname,ip,port);
 		perror("Error(clinet): can't connect\n");
-		fprintf(stderr,"errno = %i\n",errno);
+		fprintf(stderr,"errno = %i\n",c.err);
 		con_err = 4;
 		close(id);
 	err:
 		if ( func )
 			(*func)(1,work);
-		*cerr = errno;
+		*cerr = c.err;
 		return 0;
 	}
 	runlock_fork(&ft);
