@@ -21,6 +21,7 @@
 #include	"memory_debug.h"
 #include	"utils.h"
 #include	"fcntl.h"
+#include	"machine/fork_lock.h"
 
 extern int max_fid;
 
@@ -31,17 +32,17 @@ char * buf;
 int id;
 int i;
 	buf = d_alloc(1000,144);
+	wlock_fork();
 	id = fork();
 	if ( id == 0 ) {
-		id = open("/dev/null",O_WRONLY);
-		for ( i = 1 ; i <= OPEN_MAX ; i ++  )
+		for ( i = 1 ; i <= sys_param.max_fd ; i ++  )
 			close(i);
+		id = open("/dev/null",O_WRONLY);
 		dup(id);
-		dup(id);
-		close(id);
 		sprintf(buf,"%s &",proc);
 		system(buf);
 		exit(0);
 	}
+	wunlock_fork();
 	d_f_ree(buf);
 }
