@@ -148,9 +148,9 @@ int ret_errno;
 		argv = _argv;
 	}
 
-	fp = d_alloc(OPEN_MAX+1,130);
+	fp = d_alloc(sys_param.max_fd+1,130);
 	org = d_alloc(len,131);
-	pipe_dup = d_alloc(sizeof(int)*OPEN_MAX,131);
+	pipe_dup = d_alloc(sizeof(int)*sys_param.max_fd,131);
 
 	er = pipe(p);
 retry:
@@ -178,7 +178,7 @@ retry:
 		}
 		for ( i = 0 ; i < len ; i ++ )
 			org[i] = 0;
-		for ( i = 0 ; i < OPEN_MAX+1 ; i ++ ){
+		for ( i = 0 ; i < sys_param.max_fd+1 ; i ++ ){
 			if ( i == p[0] )
 				fp[i] = 1;
 			else	fp[i] = 0;
@@ -203,7 +203,7 @@ retry:
 			close(stpfd[j]);
 			j ++;
 		}
-		for ( ; i <= OPEN_MAX ; i ++ ) {
+		for ( ; i <= sys_param.max_fd ; i ++ ) {
 			if ( p[0] == i )
 				continue;
 			close(i);
