@@ -24,12 +24,12 @@
 
 extern int now_open_files;
 
-#define OPEN_MAX 508
+#define sys_param.max_fd 508
 
 int
 s_check_resource()
 {
-	if ( now_open_files > (OPEN_MAX/2) )
+	if ( now_open_files > (sys_param.max_fd/2) )
 		return -1;
 	return 0;
 }
@@ -40,7 +40,7 @@ s_check_resource2(int * op_max)
 int ret;
         ret = 0;
 		/*
-        for ( i = 0 ; i <= OPEN_MAX ; i ++ ) {
+        for ( i = 0 ; i <= sys_param.max_fd ; i ++ ) {
                 errno = 0;
 				mode = fcntl(i,F_GETFL);
                 if ( errno == EBADF )
@@ -53,6 +53,6 @@ int ret;
         }
 		*/
 		if ( op_max )
-			*op_max = OPEN_MAX;
+			*op_max = sys_param.max_fd;
         return ret;
 }
\ No newline at end of file
