@@ -25,8 +25,7 @@ char	endian_flag;
 void
 check_endian()
 {
-EDI e;
-	e.a = 1;
-	endian_flag = e.b[0];
+	int i=1;
+	endian_flag = *((char*)&i);
 }
 
