@@ -1192,31 +1192,26 @@ end:
 }
 
 MAP_PATH_TABLE *
-get_mpi_cp_mpt(int ses,L_CHAR * url_str,int type)
+xx_get_mpi_cp_mpt(int ses,L_CHAR * url_str,int type,
+char * __file,int __line)
 {
 MAP_PATH_INFO * mpi;
 MAP_PATH_TABLE * m,** mp;
 MAP_PATH_TABLE * m1, * m2;
 
 
-set_cpu_msg(730000);
 	mpi = get_mpi(ses,url_str,MPI_READ|(type&MPI_NOCACHE));
-set_cpu_msg(731000);
 	if ( mpi == 0 )
 		return 0;
-set_cpu_msg(732000);
 	m = 0;
 	mp = &m;
-set_cpu_msg(733000);
 	for ( m1 = mpi->mpt ; m1 ; m1 = m1->next ) {
-		m2 = copy_mpt(m1);
+		m2 = xx_copy_mpt(m1,__file,__line);
 		m2->next = 0;
 		*mp = m2;
 		mp = &m2->next;
 	}
-set_cpu_msg(734000);
 	flush_mpi(mpi);
-set_cpu_msg(735000);
 	return m;
 }
 
@@ -1285,6 +1280,8 @@ XL_SEXP * gt;
 	ret[0] = len;
 	close_session(ses);
 
+	free_mpt(t);
+
 	return ret;
 }
 
