@@ -33,23 +33,22 @@
 int
 lock_db(PMD_WORK * w)
 {
-XL_SEXP * ret;
+CALL_LOCK_DESCRIPTER ret;
 
-	ret = connect_lock(0,l_string(std_cm,w->path),"write");
-	if ( get_type(ret) != XLT_INTEGER ) {
+	ret = call_lock(l_string(std_cm,w->path),CLT_WRITE_LOCK);
+	if ( cl_error_check(ret) ) {
 		w->err = -2;
-		w->lock_id = 0;
+		w->lock_id = cl_invalid();
 		return -1;
 	}
-	w->lock_id = ret->integer.data;
+	w->lock_id = ret;
 	return 0;
 }
 
 void
 unlock_db(PMD_WORK * w)
 {
-	if ( w->lock_id )
-		connect_unlock(0,w->lock_id,l_string(std_cm,w->path));
+	call_unlock(w->lock_id);
 }
 
 
