@@ -59,6 +59,7 @@ static RCACHE_BLK routing_cache;
 static ACC_PN_RT_CACHE_HEADER * rt_cache_header;
 static PDB * rc_p;
 static int max_rt_cache_counter = 100000;
+int rt_rcache_flags;
 
 /*
 void
@@ -327,6 +328,7 @@ remake_rt_cache()
 		if ( routing_cache.err == RE_DESTROY )
 			routing_cache.err = RE_STOP;
 	}
+	routing_cache.err = RE_RUN;
 end:
 	unlock_rcache(&routing_cache);
 }
@@ -546,14 +548,19 @@ FAVT_ROOT * r;
 unsigned int start_ix,target_ix;
 RT_CACHE_LIST * lst1,* lst2, * p1, * p2;
 
+retry:
 	ret = 0;
 	local_lock_rcache(&routing_cache);
+	if ( (rt_rcache_flags & RCF_ROUTING_READ) == 0 )
+		goto idle;
 	if ( routing_cache.err == 0 )
 		goto idle;
 	if ( routing_cache.err < 0 ) {
+		unlock_rcache(&routing_cache);
 		remake_rt_cache();
 		if ( routing_cache.err <= 0 )
-			goto idle;
+			goto idle2;
+		goto retry;
 	}
 	rlock_rcache(&routing_cache);
 	lst1 = lst2 = 0;
@@ -606,6 +613,7 @@ end:
 idle:
 	unlock_rcache(&routing_cache);
 	remake_rt_cache();
+idle2:
 	return ret;
 }
 
@@ -706,7 +714,8 @@ STRING_INDEX * ix;
 	}
 	else {
 		ix = n->data;
-		favt_delete(r,&r->node,ix,favt_cmp_string_1);
+		n = favt_delete(r,&r->node,ix,favt_cmp_string_1);
+		favt_free_node(n);
 	}
 }
 
@@ -719,6 +728,7 @@ L_CHAR * ptr;
 int len;
 int p_pos,p_len;
 FAVT_ROOT * r;
+FAVT_NODE * n;
 RTC_TIMER_INDEX ix;
 	d = read_filespace(rc_p,p_data);
 	if ( d == 0 ) {
@@ -747,7 +757,8 @@ RTC_TIMER_INDEX ix;
 		routing_cache.err = RE_DESTROY;
 		return;
 	}
-	favt_delete(r,&r->node,&ix,cmp_rtc_timer);
+	n = favt_delete(r,&r->node,&ix,cmp_rtc_timer);
+	favt_free_node(n);
 	rt_cache_header->d.count --;
 	_purge_rt_cache_header();
 }
@@ -923,6 +934,7 @@ PN_RT_CACHE_ELEMENT el;
 int cnt;
 
 
+retry:
 	ret = -1;
 	local_lock_rcache(&routing_cache);
 	if ( routing_cache.err == 0 )
@@ -931,9 +943,11 @@ int cnt;
 	mp->update = get_xltime();
 
 	if ( routing_cache.err <= 0 ) {
+		unlock_rcache(&routing_cache);
 		remake_rt_cache();
 		if ( routing_cache.err <= 0 )
-			goto idle;
+			goto idle2;
+		goto retry;
 	}
 	wlock_rcache(&routing_cache);
 	if ( rc_p == 0 ) {
@@ -968,6 +982,7 @@ end:	{}
 idle:
 	unlock_rcache(&routing_cache);
 	remake_rt_cache();
+idle2:
 	return ret;
 }
 
@@ -980,13 +995,16 @@ RT_CACHE_LIST * lst, * p;
 FAVT_ROOT * r;
 unsigned int ix;
 
+retry:
 	local_lock_rcache(&routing_cache);
 	if ( routing_cache.err == 0 )
 		goto idle;
 	if ( routing_cache.err <= 0 ) {
+		unlock_rcache(&routing_cache);
 		remake_rt_cache();
 		if ( routing_cache.err <= 0 )
-			goto idle;
+			goto idle2;
+		goto retry;
 	}
 	wlock_rcache(&routing_cache);
 	if ( rc_p == 0 ) {
@@ -1011,6 +1029,7 @@ end:	{}
 idle:
 	unlock_rcache(&routing_cache);
 	remake_rt_cache();
+idle2:
 	return;
 }
 
@@ -1023,20 +1042,33 @@ flush_rt_cache()
 	unlock_rcache(&routing_cache);
 }
 
+
 void
-enable_rt_cache()
+_disable_rt_cache()
 {
-	local_lock_rcache(&routing_cache);
-	new_rcache_blk(&routing_cache,"routing.rch");
-	unlock_rcache(&routing_cache);
+	_close_rt_cache();
+	routing_cache.err = RE_IDLE;
 }
 
+
 void
 disable_rt_cache()
 {
 	local_lock_rcache(&routing_cache);
-	_close_rt_cache();
-	routing_cache.err = RE_IDLE;
+	_disable_rt_cache();
+	rt_rcache_flags = 0;
 	unlock_rcache(&routing_cache);
 }
 
+
+
+void
+enable_rt_cache(int flags)
+{
+	local_lock_rcache(&routing_cache);
+	if ( flags & (RCF_ROUTING|RCF_ROUTING_READ) )
+		new_rcache_blk(&routing_cache,"routing.rch");
+	else 	_disable_rt_cache();
+	rt_rcache_flags = flags;
+	unlock_rcache(&routing_cache);
+}
