@@ -747,12 +747,6 @@ REAL1 dummy;
 }
 
 
-void
-change_mh_memtype(MAP_HISTORY * mh,int no)
-{
-	for ( ; mh ; mh = mh->next )
-		change_memtype(mh,no);
-}
 
 MAP_HISTORY *
 add_mh(MAP_HISTORY * mh1,MAP_HISTORY * mh2)
