@@ -697,7 +697,7 @@ XL_SEXP * rec;
 		goto err;
 	if ( l_strcmp(p->url,start) == 0 ) {
 		for ( p1 = p ; p1->next ; p1 = p1->next );
-		if ( l_strcmp(p1->url,target) )
+		if ( p != p1 && l_strcmp(p1->url,target) )
 			goto err;
 	}
 	else if ( l_strcmp(p->url,target) == 0 ) {
@@ -708,9 +708,11 @@ XL_SEXP * rec;
 			p2->next = p1;
 			p1 = p2;
 		}
-		p = p1;
-		if ( l_strcmp(p->url,start) )
+		if ( p1->next && l_strcmp(p1->url,start) ) {
+			p = p1;
 			goto err;
+		}
+		p = p1;
 	}
 	else	goto err;
 	r->head = p;
@@ -1480,6 +1482,21 @@ L_CHAR * map;
 	flush_rt_cache();
 }
 
+MP_ROUTE *
+identify_routing(L_CHAR * start)
+{
+MP_ROUTE * ret;
+MP_PATH * path;
+	ret = d_alloc(sizeof(*ret),22);
+	memset(ret,0,sizeof(*ret));
+	ret->head = ret->tail = path = d_alloc(sizeof(*path),22);
+	memset(path,0,sizeof(*path));
+	path->url = ll_copy_str(start,33);
+	ret->sts = RS_COPY;
+	ret->lock = 1;
+	return ret;
+}
+
 MP_ROUTE *
 resolve_route(L_CHAR * start,L_CHAR * target,int wait_flag)
 {
@@ -1489,6 +1506,8 @@ MP_ROUTE * ret, * _ret;
 int sts;
 
 
+	if ( l_strcmp(start,target) == 0 )
+		return identify_routing(start);
 	ret = 0;
 	lock_task(route_lock);
 	switch ( wait_flag ) {
@@ -1562,7 +1581,9 @@ end:
 	if ( ret == MP_NO_ROUTE )
 		_ret = MP_NO_ROUTE;
 	else if ( ret ) {
-		_ret = _copy_route(ret);
+		if ( ret->head && ret->head->next == 0 )
+			_ret = 0;
+		else	_ret = _copy_route(ret);
 		_flush_route(ret);
 	}
 	else	_ret = 0;
