@@ -689,12 +689,6 @@ RADAR_LUMP * ret, * ll;
 	return ret;
 }
 
-void
-change_rl_memtype(RADAR_LUMP * ll,int no)
-{
-	for ( ; ll ; ll = ll->next )
-		change_memtype(ll,no);
-}
 
 void
 _delete_lump_crd_node_from_crd(RADAR_CRD * c)
@@ -3516,7 +3510,6 @@ T_LOAD_TO_BEAM * n;
 		}
 
 		rl = n->rl;
-change_rl_memtype(rl,1650);
 		q = n->query;
 		_conv_min = n->min;
 		_conv_max = n->max;
