@@ -1435,7 +1435,6 @@ set_t_msg(26);
 	for ( i = 0 ; i < ptr_len ; i ++ )
 		reso[i] = 1;
 	mh = add_mh(&env.flame_base_display_map,wf->mh);
-change_mh_memtype(mh,1668);
 
 	map_from_flame(mh,ptr,reso,ptr_len);
 	*name = get_url_str2(&env.flame_base->draw->h.entry);
@@ -1942,7 +1941,6 @@ printf("REFERENCE\n");
 		else	no_list = 0;
 		mh = add_mh(&env.flame_base_display_map,
 			wf->mh);
-change_mh_memtype(mh,1669);
 		p.x = x;
 		p.y = y;
 		org = p;
@@ -2193,7 +2191,6 @@ int ret;
 
 	for ( wf = env.flame ; wf ; wf = wf->next ) {
 		sw.mh = add_mh(&env.flame_base_display_map,wf->mh);
-change_mh_memtype(sw.mh,1670);
 		sw.select_obj = obj;
 		sw.map = 0;
 		sw.color.c = 0x3ff;
