@@ -149,6 +149,10 @@ check_map_ptr(MAP_PATH * mp)
 {
 int i;
 	for ( i = 0 ; i < ACRP_DIR_NOS ; i ++ ) {
+		if ( mp->ent.dir[i].hops < 0 )
+			continue;
+		if ( mp->ent.dir[i].map == 0 )
+			continue;
 		if ( l_strcmp(mp->ent.dir[i].map,mp->map) == 0 )
 			return 0;
 	}
