@@ -173,7 +173,7 @@ unsigned int pmd_interval;
 unsigned int pmd_time;
 XL_SEXP * _interval, * _time;
 XL_SEXP * _pmd_interval, * _pmd_time;
-XL_SEXP * lr;
+CALL_LOCK_DESCRIPTER lr;
 L_CHAR * _filename;
 extern L_CHAR * sys_path;
 int len,slen,total;
@@ -279,7 +279,7 @@ set_mapping(
 	unsigned int pmd_interval)
 {
 XL_SEXP * mpt, * gv;
-XL_SEXP * lr;
+CALL_LOCK_DESCRIPTER lr;
 L_CHAR * _filename;
 extern L_CHAR * sys_path;
 int len,slen,total;
@@ -325,7 +325,7 @@ STREAM * st;
 	}
 	l_strcpy(&_filename[total],l_string(std_cm,".mpt"));
 
-	lr = connect_lock(gv,_filename,"write");
+	lr = call_lock(_filename,CLT_WRITE_LOCK);
 
 	st = s_open_file(
 		n_string(std_cm,_filename),
@@ -341,7 +341,8 @@ STREAM * st;
 	s_close(st);
 
 end:
-	connect_unlock(gv,lr->integer.data,_filename);
+
+	call_unlock(lr);
 
 	d_f_ree(_filename);
 	return 0;
@@ -351,7 +352,7 @@ end:
 int
 set_par_chi(L_CHAR * filename,XL_SEXP * s,char * prefix)
 {
-XL_SEXP * lr;
+CALL_LOCK_DESCRIPTER lr;
 L_CHAR * _filename;
 extern L_CHAR * sys_path;
 int len,slen,total;
@@ -375,7 +376,7 @@ XL_SEXP * gv;
 	l_strcpy(&_filename[total],l_string(std_cm,prefix));
 	gv = n_get_symbol("?xl");
 
-	lr = connect_lock(gv,_filename,"write");
+	lr = call_lock(_filename,CLT_WRITE_LOCK);
 
 	st = s_open_file(
 		n_string(std_cm,_filename),
@@ -391,7 +392,7 @@ XL_SEXP * gv;
 	s_close(st);
 
 end:
-	connect_unlock(gv,lr->integer.data,_filename);
+	call_unlock(lr);
 	d_f_ree(_filename);
 	return 0;
 }
@@ -411,7 +412,6 @@ L_CHAR * f;
 L_CHAR * _target;
 int len;
 
-set_cpu_msg(610);
 	gt = n_get_symbol("Set");
 	set_attribute(gt,
 		l_string(std_cm,"option"),
@@ -422,7 +422,6 @@ set_cpu_msg(610);
 	l_strcpy(&_target[len],l_string(std_cm,prefix));
 	get_url2(&u,_target,1235);
 	d_f_ree(_target);
-set_cpu_msg(611);
 	ret = remote_session(
 		gblisp_top_env0,
 		ses,
@@ -456,18 +455,14 @@ set_cpu_msg(611);
 			-1),
 			-1),
 		0,0,0);
-set_cpu_msg(612);
 	d_f_ree(f);
 	free_url(&u);
 	if ( get_type(ret) == XLT_PAIR ) {
 		ret = get_el(ret,1);
-set_cpu_msg(613);
 		if ( get_type(ret) != XLT_INTEGER )
 			return 0;
-set_cpu_msg(614);
 		return ret->integer.data;
 	}
-set_cpu_msg(615);
 	return 0;
 	
 }
@@ -519,9 +514,6 @@ printf("target %s\n",n_string(std_cm,_target));
 			-1),
 			-1),
 		0,0,0);
-printf("del ret = ");
-print_sexp(s_stdout,ret,0);
-printf("\n");
 	d_f_ree(f);
 	free_url(&u);
 	return 0;
@@ -659,14 +651,12 @@ unsigned int pmd_interval1,pmd_interval2;
 unsigned int _pmd_interval;
 unsigned int mod;
 
-set_cpu_msg(50);
 
 	if ( check_mapping(filename,
 			&time,
 			&interval,
 			&pmd_time,
 			&pmd_interval) < 0 ) {
-set_cpu_msg(51);
 		if ( force == 0 || force == 2 ) {
 			if ( pmd_time == 0 || pmd_time <= get_xltime() ) {
 				force += 4;
@@ -686,14 +676,9 @@ set_cpu_msg(51);
 		}
 	}
 
-set_cpu_msg(52);
 next:
-set_cpu_msg(52);
 	mod = get_file_modify(filename,".mta");
 	meta = get_mapping(filename,".mta");
-set_cpu_msg(53);
-
-
 	if ( meta == 0 ) {
 		log_printf(LOG_WARNING,"MP: cannot access metadata of the %s",
 			n_string(std_cm,filename));
@@ -721,12 +706,9 @@ set_cpu_msg(53);
 	src = get_full_url(filename,src);
 	dest = get_full_url(filename,dest);
 	map = get_full_my_url(filename);
-set_cpu_msg(54);
 	if ( force == 3 ) {
-set_cpu_msg(55);
 		delete_target(ses,src,src,dest,map,_dp,".par");
 		delete_target(ses,dest,src,dest,map,_dp,".chi");
-set_cpu_msg(56);
 		d_f_ree(src);
 		d_f_ree(dest);
 		d_f_ree(map);
@@ -742,7 +724,6 @@ set_cpu_msg(56);
 
 		pmd_interval1 = lump_trigger(ses,src,map,pmd_interval);
 		pmd_interval2 = lump_trigger(ses,dest,map,pmd_interval);
-
 		pmd_interval = get_next_pmd_interval(
 			pmd_interval1,pmd_interval2,interval,pmd_interval);
 
@@ -770,26 +751,19 @@ set_cpu_msg(56);
 
 	}
 
-
-set_cpu_msg(61);
 	pitch1 = set_target(ses,src,src,dest,map,_dp,".par",interval,mod);
 	pitch2 = set_target(ses,dest,src,dest,map,_dp,".chi",interval,mod);
 
-
-set_cpu_msg(62);
 	d_f_ree(src);
 	d_f_ree(dest);
 	d_f_ree(map);
-set_cpu_msg(63);
+
 	interval = get_next_interval(pitch1,pitch2,interval);
-set_cpu_msg(64);
 	if ( force == 2 )
 		_interval = rand()%interval;
 	else	_interval = interval;
 	time = get_xltime() + _interval;
-set_cpu_msg(66);
 	set_mapping(filename,time,interval,pmd_time,pmd_interval);
-set_cpu_msg(67);
 
 
 	if ( pmd_interval > _interval )
@@ -910,7 +884,6 @@ static int trace_force = 2;
 			er_panic("trace_mapping(3)");
 		}
 		gc_push(0,0,"trace mapping");
-ss_printf("MAP %ls\n",t->string.data);
 		interval = ping_mapping(ses,t->string.data,trace_force);
 		gc_pop(0,0);
 		if ( interval >= 0 )
