@@ -57,7 +57,7 @@ int interval;
 	interval = mp_counter();
 	set_idle_interval(0);
 
-	cpu_nos = cpu = numofcpu();
+	cpu_nos = cpu = sys_param.cpu;
 
 	log_printf(LOG_SYSTEM,"management process (MP) is comming up : status = %c",
 			stab_status);
@@ -165,6 +165,7 @@ TICK_QUE * tq;
 		if ( t <= tt - MP_TASK_HANGUP_LIMIT ) {
 			gc_push(0,0,"hangup_watchdog");
 			log_printf(LOG_DEBUG,"MP hangup!!");
+			ss_printf("MP hangup!!");
 			if ( tq ) {
 				if ( tq->filename )
 					log_printf(LOG_DEBUG,
@@ -276,7 +277,12 @@ if ( t1->filename )
 log_printf(LOG_DEBUG,">>> %s %i %i\n",n_string(std_cm,t1->filename),t1->type,get_tid());
 else
 log_printf(LOG_DEBUG,">>> %i %i\n",t1->type,get_tid());
-
+/*
+if ( t1->filename )
+ss_printf(">>> %s %i %i\n",n_string(std_cm,t1->filename),t1->type,get_tid());
+else
+ss_printf(">>> %i %i\n",t1->type,get_tid());
+*/
 		gc_push(0,0,"acrp_task");
 		switch ( t1->type ) {
 		case TQT_CRD:
