@@ -23,11 +23,8 @@
 #include	"machine/include.h"
 #include	"long_char.h"
 #include	"xllisp.h"
+#include	"u_file.h"
 
-#define UTC_00_00_00_01_01_2001	978307200
-
-#define TFMT_UNIX	1
-#define TFMT_W3C_DTF	2
 
 typedef struct url {
 	L_CHAR *		proto;
@@ -75,21 +72,17 @@ typedef struct nested_lock {
 	int		cnt;
 } NESTED_LOCK;
 
-typedef struct _u_stat {
-	unsigned int		us_atime;
-	unsigned int		us_mtime;
-	unsigned int		us_ctime;
-} U_STAT;
-
-int u_stat(char * path,U_STAT * buf);
-
 void init_thread_area(THREAD_AREA * ta,THREAD_AREA * ta_param);
 void * get_my_area(THREAD_AREA *);
 void close_thread_area();
 int scan_ta(THREAD_AREA * ta,int (*func)(),void * work);
 
-char * copy_str(char *);
-L_CHAR * ll_copy_str(L_CHAR *,int);
+char * xx_copy_str(char *,char *,int);
+#define copy_str(x)	xx_copy_str(x,__FILE__,__LINE__)
+
+
+L_CHAR * xx_ll_copy_str(L_CHAR *,char *,int);
+#define ll_copy_str(p,no)	xx_ll_copy_str((p),__FILE__,__LINE__)
 L_CHAR * nl_copy_str(CODE_METHOD *,char *);
 char * ln_copy_str(CODE_METHOD *,L_CHAR*);
 int get_url(URL *,L_CHAR *);
@@ -171,4 +164,5 @@ char * change_delim_str(char * buf);
 L_CHAR * change_delim_l_char(L_CHAR * buf);
 char * normalize_delim_str(char * buf);
 
+
 #endif
