@@ -23,6 +23,7 @@
 #include	"r64.h"
 #include	"r64_types.h"
 #include	"machine/include.h"
+#include 	"u_file.h"
 
 int
 _r64_flush(R64_FILE * f,R64_CACHE_ENT * ce)
@@ -32,10 +33,10 @@ int vol;
 int er;
 unsigned int size;
 	ofs1 = CH_OFS2_FILE(f,ce);
-	size = lseek64(f->fd,0,SEEK_END);
+	size = u_lseek64(f->fd,0,SEEK_END);
 	if ( ofs1 > size )
 		_fill_background(f,ofs1-size);
-	ofs2 = lseek64(f->fd,ofs1,SEEK_SET);
+	ofs2 = u_lseek64(f->fd,ofs1,SEEK_SET);
 /*
 if ( ofs1 > 0x7fffffff )
 printf("W over %x %x %x\n",ofs1,size,ofs2);
@@ -45,7 +46,7 @@ printf("W over %x %x %x\n",ofs1,size,ofs2);
 		return -1;
 	}
 retry:
-	er = write(f->fd,(char*)ce->buf,vol = ENT_VOL(f,ce));
+	er = u_write(f->fd,(char*)ce->buf,vol = ENT_VOL(f,ce));
 	if ( er < vol ) {
 		if ( errno == EAGAIN )
 			goto retry;
