@@ -134,7 +134,6 @@ PATH_ELEMENT * pl;
 					(len+1)*sizeof(PATH_ELEMENT));
 			pl = &ppp->path[len];
 			pl->name = copy_str("$");
-change_memtype(pl->name,1012);
 			pl->type = PE_DIR;
 		}
 		else {
@@ -145,7 +144,6 @@ change_memtype(pl->name,1012);
 					(len+1)*sizeof(PATH_ELEMENT));
 			pl = &ppp->path[len];
 			pl->name = ln_copy_str(std_cm,buf);
-change_memtype(pl->name,1013);
 			d_f_ree(buf);
 			if ( *p == '/' )
 				pl->type = PE_DIR;
@@ -232,12 +230,10 @@ int i;
 		for ( i = 0 ; i < pp->path_len ; i ++ )
 {
 			ret->path[i].name = copy_str(ret->path[i].name);
-change_memtype(ret->path[i].name,1014);
 }
 		pe = &ret->path[pp->path_len];
 		pe->type = type;
 		pe->name = copy_str(name);
-change_memtype(pe->name,1015);
 		pe->count = 0;
 		ret->next = 0;
 		ret->type = 0;
@@ -249,7 +245,6 @@ change_memtype(pe->name,1015);
 		pe = &ret->path[0];
 		pe->type = type;
 		pe->name = copy_str(name);
-change_memtype(pe->name,1016);
 		pe->count = 0;
 		ret->next = 0;
 		ret->type = 0;
@@ -267,7 +262,6 @@ struct dirent * d;
 PATH_PATTERN * pp,* pp1;
 	if ( given_pp == 0 ) {
 		buffer = copy_str(".");
-change_memtype(buffer,1017);
 	}
 	else	buffer = make_name(given_pp);
 	dp = opendir(buffer);
@@ -408,14 +402,20 @@ int i,j,cnt;
 			case PE_DIR:
 				for ( cnt = 0;
 						cnt < ia->path[i].count;
-						cnt ++ , j ++ )
+						cnt ++ , j ++ ) {
+					if ( j >= pp->path_len )
+						return 0;
 					if ( pp->path[j].type == PE_FILE )
 						return 0;
+				}
 				break;
 			case PE_DIR_FILE:
 				for ( cnt = 0;
 						cnt < ia->path[i].count;
-						cnt ++ , j ++ );
+						cnt ++ , j ++ ) {
+					if ( j >= pp->path_len )
+						return 0;
+				}
 				break;
 			}
 		}
@@ -488,10 +488,7 @@ int i;
 	ret->path = d_alloc(sizeof(PATH_ELEMENT)*ret->path_len,616);
 	memcpy(ret->path,pp->path,sizeof(PATH_ELEMENT)*ret->path_len);
 	for ( i = 0 ; i < ret->path_len ; i ++ )
-{
 		ret->path[i].name = copy_str(ret->path[i].name);
-change_memtype(ret->path[i].name,1018);
-}
 	return ret;
 }
 
