@@ -1080,6 +1080,7 @@ int key;
 XL_INTERPRETER * xli;
 
 retry:
+	wait_rs_queue();
 	lock_task(xli_lock);
 	for ( key = 0 ; key < INTERPRETER_HASH_SIZE ; key ++ )
 		for ( xli = interpreter_hash[key]; xli ; xli = xli->next ) {
@@ -1167,6 +1168,7 @@ close_all_interpreter()
 XL_INTERPRETER * xli, * xli2, * xli3;
 int tid;
 int i;
+	_wait_rs_queue();
 	xli = _get_my_xli();
 	for ( i = 0 ; i < INTERPRETER_HASH_SIZE ; i ++ ) {
 		xli2 = interpreter_hash[i];
